pub struct FetchProvidersForEmailRequestBodyPayload { /* private fields */ }Expand description
Request body payload for the fetch providers for email API.
See also API reference.
Implementations
Sourceimpl FetchProvidersForEmailRequestBodyPayload
impl FetchProvidersForEmailRequestBodyPayload
Sourcepub fn new(identifier: String, continue_uri: String) -> Self
pub fn new(identifier: String, continue_uri: String) -> Self
Creates a new request body payload for the fetch providers for email API.
See also API reference.
Arguments
identifier- User’s email addresscontinue_uri- The URI to which the IDP redirects the user back. For this use case, this is just the current URL.