pub struct VerifyPasswordResetCodeRequestBodyPayload { /* private fields */ }Expand description
Request body payload for the verify password reset code API.
See also API reference.
Implementations
Sourceimpl VerifyPasswordResetCodeRequestBodyPayload
impl VerifyPasswordResetCodeRequestBodyPayload
Sourcepub fn new(oob_code: String) -> Self
pub fn new(oob_code: String) -> Self
Creates a new request body payload for the verify password reset code API.
See also API reference.
Arguments
oob_code- The email action code sent to the user’s email for resetting the password.